@@ -14,7 +14,7 @@ import numpy as np
 
 from ginga.misc import Bunch, Callback
 from ginga.fonts import font_asst
-from ginga.util.paths import icondir
+from ginga.util.paths import icondir, app_icon_path
 import ginga.toolkit
 
 import gi
@@ -275,7 +275,7 @@ class MultiDragDropTreeView(Gtk.TreeView):
 
 class MDISubWindow(Callback.Callbacks):
 
-    def __init__(self, widget, label):
+    def __init__(self, widget, label, iconpath=None):
         super(MDISubWindow, self).__init__()
 
         self.widget = widget
@@ -284,6 +284,15 @@ class MDISubWindow(Callback.Callbacks):
         vbox.set_border_width(4)
 
         hbox = Gtk.HBox()
+
+        # set window icon
+        if iconpath is None:
+            iconpath = app_icon_path
+        pixbuf = pixbuf_new_from_file_at_size(iconpath, 32, 32)
+        self.image = Gtk.Image.new_from_pixbuf(pixbuf)
+        hbox.pack_start(self.image, False, False, 2)
+
+        # titlebar label
         evbox = Gtk.EventBox()
         evbox.add(label)
         modify_bg(evbox, "gray90")
@@ -291,9 +300,22 @@ class MDISubWindow(Callback.Callbacks):
         self.evbox = evbox
         hbox.pack_start(evbox, True, True, 2)
 
-        close = Gtk.Button("X")
-        maxim = Gtk.Button("^")
-        minim = Gtk.Button("_")
+        # titlebar buttons
+        iconfile = os.path.join(icondir, "close.svg")
+        pixbuf = pixbuf_new_from_file_at_size(iconfile, 24, 24)
+        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        close = Gtk.Button()
+        close.set_image(image)
+        iconfile = os.path.join(icondir, "maximize.svg")
+        pixbuf = pixbuf_new_from_file_at_size(iconfile, 24, 24)
+        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        maxim = Gtk.Button()
+        maxim.set_image(image)
+        iconfile = os.path.join(icondir, "minimize.svg")
+        pixbuf = pixbuf_new_from_file_at_size(iconfile, 24, 24)
+        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        minim = Gtk.Button()
+        minim.set_image(image)
         hbox.pack_start(minim, False, False, 0)
         hbox.pack_start(maxim, False, False, 0)
         hbox.pack_start(close, False, False, 0)
@@ -326,6 +348,10 @@ class MDISubWindow(Callback.Callbacks):
         minim.connect('clicked', lambda *args: self.make_callback('minimize'))
         close.connect('clicked', lambda *args: self.make_callback('close'))
 
+    def set_icon(self, iconpath):
+        pixbuf = pixbuf_new_from_file_at_size(iconpath, 32, 32)
+        self.image.set_from_pixbuf(pixbuf)
+
     def raise_(self):
         window = self.frame.get_window()
         if window is not None:
