@@ -12,12 +12,11 @@ import time
 import tempfile
 import threading
 import logging
-import platform
 import atexit
 import shutil
 import inspect
-import warnings
 from collections import OrderedDict
+import webbrowser
 
 # Local application imports
 from ginga import cmap, imap
@@ -26,12 +25,13 @@ from ginga.util import catalog, iohelper, loader, toolbox
 from ginga.util import viewer as gviewer
 from ginga.canvas.CanvasObject import drawCatalog
 from ginga.modes import modeinfo
+from ginga.doc import download_doc
 
 # GUI imports
 from ginga.gw import GwHelp, GwMain, PluginManager
 from ginga.gw import Widgets, Viewers, Desktop
-from ginga import toolkit
 from ginga.fonts import font_asst
+from ginga.util.paths import icondir as icon_dir
 
 # Version
 from ginga import __version__
@@ -40,30 +40,9 @@ from ginga import __version__
 from ginga.rv.Channel import Channel
 from ginga.rv.rvmode import RVMode
 
-have_docutils = False
-try:
-    from docutils.core import publish_string
-    have_docutils = True
-except ImportError:
-    pass
 
-
-#pluginconfpfx = 'plugins'
 pluginconfpfx = None
 
-package_home = os.path.split(sys.modules['ginga.version'].__file__)[0]
-
-# pick up plugins specific to our chosen toolkit
-tkname = toolkit.get_family()
-if tkname is not None:
-    # TODO: this relies on a naming convention for widget directories!
-    # TODO: I think this can be removed, since the widget specific
-    # plugin directories have been deleted
-    child_dir = os.path.join(package_home, tkname + 'w', 'plugins')
-    sys.path.insert(0, child_dir)
-
-icon_path = os.path.abspath(os.path.join(package_home, 'icons'))
-
 
 class ControlError(Exception):
     pass
@@ -87,7 +66,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # Create general preferences
         self.prefs = preferences
         settings = self.prefs.create_category('general')
-        settings.add_defaults(fixedFont=None,
+        settings.add_defaults(appname='ginga',
+                              title="Ginga",
+                              fixedFont=None,
                               serifFont=None,
                               sansFont=None,
                               channel_follows_focus=False,
@@ -99,6 +80,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                               save_primary_header=True,
                               inherit_primary_header=False,
                               cursor_interval=0.050,
+                              confirm_shutdown=True,
                               download_folder=None,
                               save_layout=False,
                               channel_prefix="Image")
@@ -135,6 +117,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.cur_channel = None
         self.wscount = 0
         self.statustask = None
+        self.appname = settings.get('appname', 'ginga')
 
         # Load bindings preferences
         bindprefs = self.prefs.create_category('bindings')
@@ -176,7 +159,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         # GUI initialization
         self.w = Bunch.Bunch()
-        self.iconpath = icon_path
+        self.iconpath = icon_dir
         self.main_wsname = None
         self._lastwsname = None
         self.ds = None
@@ -186,13 +169,13 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self._rsize = None
 
         self.filesel = None
-        self.menubar = None
         self.gui_dialog_lock = threading.RLock()
         self.gui_dialog_list = []
         self.w.root = None
         # fullscreen viewer and top-level widget
         self.fs_viewer = None
         self.w.fscreen = None
+        self._help = Bunch.Bunch(remember_choice=False, choice=0)
 
         # enables reference-viewer specific bindings
         RVMode.set_shell_ref(self)
@@ -216,7 +199,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         return self.make_timer()
 
     def stop(self):
-        self.logger.info("shutting down Ginga...")
+        self.logger.info(f"shutting down {self.appname}...")
         self.timer_factory.quit()
         self.ev_quit.set()
         self.logger.debug("should be exiting now")
@@ -341,8 +324,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
             pfx = spec.get('pfx', pluginconfpfx)
             path = spec.get('path', None)
-            self.mm.load_module(spec.module, pfx=pfx, path=path)
             self.plugins.append(spec)
+            if spec.get('enabled', True):
+                self.mm.load_module(spec.module, pfx=pfx, path=path)
 
         except Exception as e:
             self.logger.error("Unable to load local plugin '%s': %s" % (
@@ -355,8 +339,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
             pfx = spec.get('pfx', pluginconfpfx)
             path = spec.get('path', None)
-            self.mm.load_module(spec.module, pfx=pfx, path=path)
             self.plugins.append(spec)
+            if spec.get('enabled', True):
+                self.mm.load_module(spec.module, pfx=pfx, path=path)
 
             self.gpmon.load_plugin(name, spec)
 
@@ -365,8 +350,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                 name, str(e)))
 
     def add_plugin(self, spec):
-        if not spec.get('enabled', True):
-            return
         ptype = spec.get('ptype', 'local')
         if ptype == 'global':
             self.add_global_plugin(spec)
@@ -407,10 +390,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         for spec in self.plugins:
             name = spec.setdefault('name', spec.get('klass', spec.module))
-            hidden = spec.get('hidden', False)
-            if not hidden:
-                self.add_plugin_menu(name, spec)
-
             start = spec.get('start', True)
             # for now only start global plugins that have start==True
             # channels are not yet created by this time
@@ -443,10 +422,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         """
         Provide help text for the user.
 
-        This method will convert the text as necessary with docutils and
-        display it in the WBrowser plugin, if available.  If the plugin is
-        not available and the text is type 'rst' then the text will be
-        displayed in a plain text widget.
+        This method will trim the text as necessary and display it in
+        the text widget.
 
         Parameters
         ----------
@@ -454,69 +431,100 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             Category of help to show.
 
         text : str
-            The text to show.  Should be plain, HTML or RST text
+            The text to show.
 
         text_kind : str (optional)
-            One of 'plain', 'html', 'rst'.  Default is 'plain'.
+            One of 'plain' or 'rst'.  Default is 'plain'.
 
         trim_pfx : int (optional)
             Number of spaces to trim off the beginning of each line of text.
 
         """
-
         if trim_pfx > 0:
             # caller wants to trim some space off the front
             # of each line
             text = toolbox.trim_prefix(text, trim_pfx)
 
-        if text_kind == 'rst':
-            # try to convert RST to HTML using docutils
-            try:
-                overrides = {'input_encoding': 'ascii',
-                             'output_encoding': 'utf-8'}
-                text_html = publish_string(text, writer_name='html',
-                                           settings_overrides=overrides)
-                # docutils produces 'bytes' output, but webkit needs
-                # a utf-8 string
-                text = text_html.decode('utf-8')
-                text_kind = 'html'
-
-            except Exception as e:
-                self.logger.error("Error converting help text to HTML: %s" % (
-                    str(e)))
-                # revert to showing RST as plain text
+        if text_kind in ['rst', 'plain']:
+            self.show_help_text(name, text)
 
         else:
             raise ValueError(
                 "I don't know how to display text of kind '%s'" % (text_kind))
 
-        if text_kind == 'html':
-            self.help(text=text, text_kind='html')
-
-        else:
-            self.show_help_text(name, text)
-
     def help(self, text=None, text_kind='url'):
-
-        if not self.gpmon.has_plugin('WBrowser'):
-            return self.show_error("help() requires 'WBrowser' plugin")
-
-        self.start_global_plugin('WBrowser')
-
-        # need to let GUI finish processing, it seems
-        self.update_pending()
-
-        obj = self.gpmon.get_plugin('WBrowser')
-
-        if text is not None:
-            if text_kind == 'url':
-                obj.browse(text)
-            else:
-                obj.browse(text, url_is_content=True)
+        if text_kind == 'url':
+            if text is None:
+                # get top URL of external RTD docs
+                text = download_doc.get_online_docs_url(plugin=None)
+            self.show_help_url(text)
         else:
-            obj.show_help()
+            if isinstance(text, str):
+                self.show_help_text('HELP', text)
 
-    def show_help_text(self, name, help_txt, wsname='right'):
+    def show_help_url(self, url):
+        """
+        Open a URL in an external browser using Python's webbrowser module.
+        """
+        self.logger.info(f"opening '{url}' in external browser...")
+        webbrowser.open(url)
+
+    def help_plugin(self, plugin_obj, text_kind='rst', url=None):
+        """
+        Called from a plugin's default help() method. Offers to show the
+        user plugin docstring in a text widget or view the RTD doc in an
+        external web browser.
+        """
+
+        def _do_help(val, url=None):
+            if val == 1:
+                # show plain text in a text widget
+                if plugin_obj is not None:
+                    name, doc = plugin_obj._get_docstring()
+                    self.show_help_text(name, doc)
+            elif val == 2:
+                # show web page in external browser
+                if url is None:
+                    url = download_doc.get_online_docs_url(plugin=plugin_obj)
+                self.show_help_url(url)
+
+        if self._help.choice > 0:
+            # User made a decision to keep getting plugin help the same way
+            return _do_help(self._help.choice, url=url)
+
+        # Create troubleshooting dialog if downloading cannot be done
+        dialog = Widgets.Dialog(title="Show documentation",
+                                parent=self.w.root,
+                                modal=False,
+                                buttons=[("Cancel", 0),
+                                         ("Show RST text", 1),
+                                         ("Use external browser", 2),
+                                         ])
+        dialog.buttons[0].set_tooltip("Skip help")
+        dialog.buttons[1].set_tooltip("Show local docstring for plugin help")
+        dialog.buttons[2].set_tooltip("Show online web documentation in external browser")
+        vbox = dialog.get_content_area()
+        dialog_text = Widgets.TextArea(wrap=True, editable=False)
+        dialog_text.set_text("How would you like to see help?")
+        vbox.add_widget(dialog_text, stretch=1)
+        cb = Widgets.CheckBox("Remember my choice for session")
+        cb.set_state(False)
+        vbox.add_widget(cb, stretch=0)
+
+        def _remember_choice_cb(w, tf):
+            self._help.remember_choice = tf
+
+        def _do_help_cb(dialog, val, url=None):
+            if self._help.remember_choice:
+                self._help.choice = val
+            self.ds.remove_dialog(dialog)
+            _do_help(val, url=url)
+
+        cb.add_callback('activated', _remember_choice_cb)
+        dialog.add_callback('activated', _do_help_cb, url=url)
+        self.ds.show_dialog(dialog)
+
+    def show_help_text(self, name, help_txt, wsname='channels'):
         """
         Show help text in a closeable tab window.  The title of the
         window is set from ``name`` prefixed with 'HELP:'
@@ -847,7 +855,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                               "\nPlease choose an opener or cancel, for file:\n"
                               "{1:}".format(mimetype, filepath))
                     self.gui_do(self.gui_choose_file_opener, errmsg, openers,
-                                _open_file, '*', filepath)
+                                _open_file, mimetype, filepath)
 
         future = Future.Future()
         future.freeze(_check_open, warnmsg)
@@ -1099,7 +1107,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         ws = self.get_current_workspace()
         ws.cycle_wstype()
 
-    def add_workspace(self, wsname, wstype, inSpace=None):
+    def add_workspace(self, wsname, wstype, inSpace=None, use_toolbar=True):
         if inSpace is None:
             inSpace = self.main_wsname
 
@@ -1107,7 +1115,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             raise ValueError("Tab name already in use: '%s'" % (wsname))
 
         ws = self.ds.make_ws(name=wsname, group=1, wstype=wstype,
-                             use_toolbar=True)
+                             use_toolbar=use_toolbar)
         if inSpace != 'top level':
             self.ds.add_tab(inSpace, ws.widget, 1, ws.name)
         else:
@@ -1340,7 +1348,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                     num_images=None, settings=None,
                     settings_template=None,
                     settings_share=None, share_keylist=None):
-        """Create a new Ginga channel.
+        """Create a new channel.
 
         Parameters
         ----------
@@ -1506,19 +1514,19 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             text = '1/%.2fx' % (1.0 / scalefactor)
         return text
 
-    def banner(self, raiseTab=False):  # noqa
-        # NOTE: raiseTab kwarg ignored and will be deprecated
+    def banner(self):
         # load banner image
-        banner_file = os.path.join(self.iconpath, 'ginga-splash.ppm')
+        banner_file = os.path.join(self.iconpath, 'ginga-splash.png')
         image = self.load_image(banner_file)
         wd, ht = image.get_size()
 
         # create dialog for banner
         title = f"Ginga v{__version__}"
-        top = Widgets.Dialog(title=title, buttons=[["Close", 0]], modal=True)
+        top = Widgets.Dialog(title=title, parent=self.w.root,
+                             buttons=[["Close", 0]], modal=False)
 
         def _close_banner(*args):
-            top.delete()
+            self.ds.remove_dialog(top)
 
         top.add_callback('activated', _close_banner)
         vbox = top.get_content_area()
@@ -1537,7 +1545,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         vbox.add_widget(w, stretch=1)
 
         viewer.set_image(image)
-        top.show()
+        self.ds.show_dialog(top)
 
     def remove_image_by_name(self, chname, imname, impath=None):
         channel = self.get_channel(chname)
@@ -1663,10 +1671,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # TEMP: FIX ME!
         self.gpmon.ds = self.ds
 
+        self.add_callback('close', self.close_cb)
+        self.add_callback('shutdown', self.shutdown_cb)
         for win in self.ds.toplevels:
             # add delete/destroy callbacks
-            win.add_callback('close', self.quit)
-            win.set_title("Ginga")
+            win.add_callback('close', self.window_close)
+            win.set_title(self.settings.get('title', "Ginga"))
             root = win
         self.ds.add_callback('all-closed', self.quit)
 
@@ -1678,10 +1688,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             ws = self.ds.get_ws(wsname)
             self.init_workspace(ws)
 
-        if 'menu' in self.w:
-            menuholder = self.w['menu']
-            self.w.menubar = self.add_menus(menuholder)
-
         self.add_dialogs()
 
         if 'status' in self.w:
@@ -1702,116 +1708,11 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                 newname.append(c)
         return pfx + ''.join(newname)
 
-    def add_menus(self, holder):
-
-        menubar = Widgets.Menubar()
-        self.menubar = menubar
-
-        # NOTE: Special hack for Mac OS X. From the Qt documentation:
-        # "If you want all windows in a Mac application to share one
-        #  menu bar, you must create a menu bar that does not have a
-        #  parent."
-        macos_ver = platform.mac_ver()[0]
-        if len(macos_ver) > 0:
-            pass
-        else:
-            holder.add_widget(menubar, stretch=1)
-
-        # create a File pulldown menu, and add it to the menu bar
-        filemenu = menubar.add_name("File")
-
-        item = filemenu.add_name("Load Image")
-        item.add_callback('activated', lambda *args: self.gui_load_file())
-
-        item = filemenu.add_name("Remove Image")
-        item.add_callback("activated",
-                          lambda *args: self.remove_current_image())
-
-        filemenu.add_separator()
-
-        item = filemenu.add_name("Quit")
-        item.add_callback('activated', lambda *args: self.window_close())
-
-        # create a Channel pulldown menu, and add it to the menu bar
-        chmenu = menubar.add_name("Channel")
-
-        item = chmenu.add_name("Add Channel")
-        item.add_callback('activated', lambda *args: self.gui_add_channel())
-
-        item = chmenu.add_name("Add Channels")
-        item.add_callback('activated', lambda *args: self.gui_add_channels())
-
-        item = chmenu.add_name("Delete Channel")
-        item.add_callback('activated', lambda *args: self.gui_delete_channel())
-
-        # create a Window pulldown menu, and add it to the menu bar
-        wsmenu = menubar.add_name("Workspace")
-
-        item = wsmenu.add_name("Add Workspace")
-        item.add_callback('activated', lambda *args: self.gui_add_ws())
-
-        # # create a Option pulldown menu, and add it to the menu bar
-        # optionmenu = menubar.add_name("Option")
-
-        # create a Plugins pulldown menu, and add it to the menu bar
-        plugmenu = menubar.add_name("Plugins")
-        self.w.menu_plug = plugmenu
-
-        # create a Help pulldown menu, and add it to the menu bar
-        helpmenu = menubar.add_name("Help")
-
-        item = helpmenu.add_name("About")
-        item.add_callback('activated',
-                          lambda *args: self.banner(raiseTab=True))
-
-        item = helpmenu.add_name("Documentation")
-        item.add_callback('activated', lambda *args: self.help())
-
-        return menubar
-
-    def add_menu(self, name):
-        """Add a menu with name `name` to the global menu bar.
-        Returns a menu widget.
-        """
-        if self.menubar is None:
-            raise ValueError("No menu bar configured")
-        return self.menubar.add_name(name)
-
-    def get_menu(self, name):
-        """Get the menu with name `name` from the global menu bar.
-        Returns a menu widget.
-        """
-        if self.menubar is None:
-            raise ValueError("No menu bar configured")
-        return self.menubar.get_menu(name)
-
     def add_dialogs(self):
         if hasattr(GwHelp, 'FileSelection'):
             self.filesel = GwHelp.FileSelection(self.w.root.get_widget(),
                                                 all_at_once=True)
 
-    def add_plugin_menu(self, name, spec):
-        # NOTE: self.w.menu_plug is a ginga.Widgets wrapper
-        if 'menu_plug' not in self.w:
-            return
-        category = spec.get('category', None)
-        categories = None
-        if category is not None:
-            categories = category.split('.')
-        menuname = spec.get('menu', spec.get('tab', name))
-
-        menu = self.w.menu_plug
-        if categories is not None:
-            for catname in categories:
-                try:
-                    menu = menu.get_menu(catname)
-                except KeyError:
-                    menu = menu.add_menu(catname)
-
-        item = menu.add_name(menuname)
-        item.add_callback('activated',
-                          lambda *args: self.start_plugin(name, spec))
-
     def add_statusbar(self, holder):
         self.w.status = Widgets.StatusBar()
         holder.add_widget(self.w.status, stretch=1)
@@ -1926,7 +1827,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
     ####################################################
 
     def set_titlebar(self, text):
-        self.w.root.set_title("Ginga: %s" % text)
+        self.w.root.set_title("{}: {}".format(self.appname.capitalize(), text))
 
     def build_viewpane(self, settings, rgbmap=None, size=(1, 1)):
         # instantiate bindings loaded with users preferences
@@ -2108,6 +2009,15 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                             lambda w, rsp: self.delete_channel_cb(w, rsp, chname))  # noqa
 
         box = dialog.get_content_area()
+        hbox = Widgets.HBox()
+        hbox.set_border_width(4)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        img = Widgets.Image()
+        iconfile = os.path.join(icon_dir, "question.svg")
+        img.load_file(iconfile)
+        hbox.add_widget(img, stretch=0)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        box.add_widget(hbox, stretch=1)
         box.add_widget(lbl, stretch=0)
 
         self.ds.show_dialog(dialog)
@@ -2122,6 +2032,15 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                             lambda w, rsp: self.delete_tab_cb(w, rsp, tabname))
 
         box = dialog.get_content_area()
+        hbox = Widgets.HBox()
+        hbox.set_border_width(4)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        img = Widgets.Image()
+        iconfile = os.path.join(icon_dir, "question.svg")
+        img.load_file(iconfile)
+        hbox.add_widget(img, stretch=0)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        box.add_widget(hbox, stretch=1)
         box.add_widget(lbl, stretch=0)
 
         self.ds.show_dialog(dialog)
@@ -2392,12 +2311,47 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
     # CALLBACKS
     ####################################################
 
-    def window_close(self, *args):
+    def window_close(self, w):
         """Quit the application.
         """
+        # forces processing of close_cb
+        self.close()
+
+    def close_cb(self, app):
+        if not self.settings.get('confirm_shutdown', True):
+            self.quit()
+
+        # confirm close with a dialog here
+        q_quit = Widgets.Dialog(title="Confirm Quit", modal=False,
+                                parent=self.w.root,
+                                buttons=[("Cancel", False), ("Confirm", True)])
+        # necessary so it doesn't get garbage collected right away
+        self.w.quit_dialog = q_quit
+        vbox = q_quit.get_content_area()
+        vbox.set_margins(4, 4, 4, 4)
+        hbox = Widgets.HBox()
+        hbox.set_border_width(4)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        img = Widgets.Image()
+        iconfile = os.path.join(icon_dir, "warning.svg")
+        img.load_file(iconfile)
+        hbox.add_widget(img, stretch=0)
+        hbox.add_widget(Widgets.Label(""), stretch=1)
+        vbox.add_widget(hbox, stretch=1)
+        vbox.add_widget(Widgets.Label("Do you really want to quit?"))
+        q_quit.add_callback('activated', self._confirm_quit_cb)
+        q_quit.add_callback('close', lambda w: self._confirm_quit_cb(w, False))
+        q_quit.show()
+
+    def _confirm_quit_cb(self, w, tf):
+        self.w.quit_dialog.delete()
+        self.w.quit_dialog = None
+        if not tf:
+            return
+
         self.quit()
 
-    def quit(self, *args):
+    def shutdown_cb(self, app):
         """Quit the application.
         """
         self.logger.info("Attempting to shut down the application...")
@@ -2498,17 +2452,13 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         bnch = bnchs[0]
         self.ds.remove_dialog(w)
 
-        if wgts.choice is not None and wgts.choice.get_state():
+        if (wgts.choice is not None and wgts.choice.get_state() and
+            mimetype is not None):
             # user wants us to remember their choice
-            if mimetype != '*':
-                # loader is not registered for this mimetype, so go ahead
-                # and do it
-                loader.add_opener(bnch.opener, [mimetype],
-                                  priority=bnch.priority, note=bnch.note)
-            else:
-                # multiple loaders for the same mimetype--
-                # remember setting by prioritizing choice
-                bnch.priority = -1
+            # loader is not registered for this mimetype, so go ahead
+            # and do it
+            loader.add_opener(bnch.opener, [mimetype],
+                              priority=-99, note=bnch.note)
 
         self.nongui_do(open_cb, bnch.opener)
         self.__next_dialog()
@@ -2551,13 +2501,13 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             tb.add_separator()
 
             # add toolbar buttons for navigating between tabs
-            iconpath = os.path.join(self.iconpath, "prev_48.png")
+            iconpath = os.path.join(self.iconpath, "prev.svg")
             btn = tb.add_action(None, iconpath=iconpath, iconsize=(24, 24))
             btn.set_tooltip("Focus previous tab in this workspace")
             btn.add_callback('activated', lambda w: self.prev_channel_ws(ws))
             ws.extdata.w_prev_tab = btn
             btn.set_enabled(False)
-            iconpath = os.path.join(self.iconpath, "next_48.png")
+            iconpath = os.path.join(self.iconpath, "next.svg")
             btn = tb.add_action(None, iconpath=iconpath, iconsize=(24, 24))
             btn.set_tooltip("Focus next tab in this workspace")
             btn.add_callback('activated', lambda w: self.next_channel_ws(ws))
@@ -2575,13 +2525,13 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             btn = tb.add_widget(entry)
 
             # add toolbar buttons adding and deleting channels
-            iconpath = os.path.join(self.iconpath, "inbox_plus_48.png")
+            iconpath = os.path.join(self.iconpath, "inbox_plus.svg")
             btn = tb.add_action(None, iconpath=iconpath, iconsize=(24, 23))
             btn.set_tooltip("Add a channel to this workspace")
             btn.add_callback('activated',
                              lambda w: self.add_channel_auto_ws(ws))
             ws.extdata.w_new_channel = btn
-            iconpath = os.path.join(self.iconpath, "inbox_minus_48.png")
+            iconpath = os.path.join(self.iconpath, "inbox_minus.svg")
             btn = tb.add_action(None, iconpath=iconpath, iconsize=(24, 23))
             btn.set_tooltip("Delete current channel from this workspace")
             btn.add_callback('activated',
@@ -2818,16 +2768,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.update_pending()
         return True
 
-    def motion_cb(self, viewer, button, data_x, data_y):
-        """Motion event in the channel viewer window.  Show the pointing
-        information under the cursor.
-        """
-        warnings.warn("This function has been deprecated--"
-                      "use showxy() instead",
-                      DeprecationWarning)
-        self.showxy(viewer, data_x, data_y)
-        return True
-
     def dragdrop(self, chviewer, uris):
         """Called when a drop operation is performed on a channel viewer.
         We are called back with a URL and we attempt to (down)load it if it
@@ -2838,6 +2778,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.open_uris(uris, chname=chname)
         return True
 
+    def force_focus_cb(self, viewer, event, data_x, data_y):
+        chname = self.get_channel_name(viewer)
+        if chname is not None:
+            self.force_focus(chname)
+        return True
+
     def force_focus(self, chname):
         if not self.settings.get('channel_follows_focus', False):
             self.change_channel(chname, raisew=True)
@@ -2847,15 +2793,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         if hasattr(v, 'take_focus'):
             v.take_focus()
 
-    def force_focus_cb(self, viewer, event, data_x, data_y):
-        warnings.warn("This function has been deprecated--"
-                      "use force_focus() instead",
-                      DeprecationWarning)
-        chname = self.get_channel_name(viewer)
-        if chname is not None:
-            self.force_focus(chname)
-        return True
-
     def focus_cb(self, viewer, tf, name):
         """Called when ``viewer`` gets ``(tf==True)`` or loses
         ``(tf==False)`` the focus.
