@@ -31,7 +31,8 @@ __all__ = ['ReferenceViewer']
 
 default_layout = ['seq', {},
                    ['vbox', dict(name='top', width=1400, height=700),  # noqa
-                    dict(row=['hbox', dict(name='menu')],
+                    dict(row=['ws', dict(name='menubar', wstype='stack',
+                                         group=99)],
                          stretch=0),
                     dict(row=['hpanel', dict(name='hpnl'),
                      ['ws', dict(name='left', wstype='tabs',  # noqa
@@ -73,6 +74,9 @@ default_layout = ['seq', {},
 
 plugins = [
     # hidden plugins, started at program initialization
+    Bunch(module='Menubar', klass='GingaMenubar', workspace='menubar',
+          start=True, hidden=True, category='System', menu="Menubar [G]",
+          ptype='global', enabled=True),
     Bunch(module='Operations', workspace='operations', start=True,
           hidden=True, category='System', menu="Operations [G]",
           ptype='global', enabled=True),
@@ -202,6 +206,10 @@ plugins = [
 ]
 
 
+def get_plugin_spec(module=None):
+    return [spec for spec in plugins if spec['module'] == module]
+
+
 class ReferenceViewer(object):
     """
     This class exists solely to be able to customize the reference
@@ -374,7 +382,8 @@ class ReferenceViewer(object):
         # Set up preferences
         prefs = Settings.Preferences(basefolder=self.basedir, logger=logger)
         settings = prefs.create_category('general')
-        settings.set_defaults(title=self.appname.capitalize(),
+        settings.set_defaults(appname=self.appname,
+                              title=self.appname.capitalize(),
                               useMatplotlibColormaps=False,
                               widgetSet='choose',
                               WCSpkg='choose', FITSpkg='choose',
@@ -624,12 +633,13 @@ class ReferenceViewer(object):
             if plugin_name in self.plugin_dct:
                 spec = self.plugin_dct[plugin_name]
                 spec.enabled = True
+                spec.start = True
             else:
                 menu_name = f"{plugin_name} [G]"
                 spec = Bunch(name=plugin_name, module=plugin_name,
                              ptype='global', tab=plugin_name,
                              menu=menu_name, category="Custom",
-                             enabled=True,
+                             enabled=True, start=True,
                              workspace='right', pfx=pfx)
                 self.add_plugin_spec(spec)
 
