@@ -218,10 +218,7 @@ class Pan(GingaPlugin.GlobalPlugin):
 
     # CALLBACKS
 
-    def _redo(self, channel, image):
-        """NOTE: this plugin is triggered not by a CHANNEL getting a new
-        image, but by the VIEWER getting a new image, OR the viewer redrawing.
-        """
+    def redo(self, channel, image):
         if not self.gui_up:
             return
         self.logger.debug("redo")
@@ -334,7 +331,7 @@ class Pan(GingaPlugin.GlobalPlugin):
             paninfo.panimage.clear()
 
         x, y = fitsimage.get_pan()
-        points = fitsimage.get_pan_rect()
+        points = fitsimage.get_pan_bbox()
 
         limits = fitsimage.get_limits()
         width = limits[1][0] - limits[0][0]
